@@ -26,11 +26,3 @@ impl<P, D> UnconnectedSend<P, D> {
         }
     }
 }
-
-#[derive(Debug)]
-pub struct SetAttributeRequestItem<T> {
-    pub id: u16,
-    /// data size in response
-    pub size: u16,
-    pub data: T,
-}
